@@ -29,6 +29,7 @@ from ocp_resources.utils import (
     skip_existing_resource_creation_teardown,
 )
 
+
 LOGGER = get_logger(__name__)
 MAX_SUPPORTED_API_VERSION = "v2"
 
@@ -291,6 +292,7 @@ class Resource:
         STORAGECLASS_KUBERNETES_IO = "storageclass.kubernetes.io"
         SUBRESOURCES_KUBEVIRT_IO = "subresources.kubevirt.io"
         TEKTONTASKS_KUBEVIRT_IO = "tektontasks.kubevirt.io"
+        TEKTON_DEV = "tekton.dev"
         TEMPLATE_KUBEVIRT_IO = "template.kubevirt.io"
         TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
         UPLOAD_CDI_KUBEVIRT_IO = "upload.cdi.kubevirt.io"
@@ -318,9 +320,7 @@ class Resource:
         node_selector_labels=None,
         config_file=None,
         context=None,
-        label=None,
         timeout_seconds=TIMEOUT_1MINUTE,
-        api_group=None,
     ):
         """
         Create an API resource
@@ -338,11 +338,8 @@ class Resource:
             config_file (str): Path to config file for connecting to remote cluster.
             context (str): Context name for connecting to remote cluster.
             timeout_seconds (int): timeout for a get api call, call out be terminated after this many seconds
-            label (dict): Resource labels
-            api_group (str): Resource API group; will overwrite API group definition in resource class
 
         """
-        self.api_group = api_group or self.api_group
         if not self.api_group and not self.api_version:
             raise NotImplementedError(
                 "Subclasses of Resource require self.api_group or self.api_version to be defined"
@@ -355,7 +352,6 @@ class Resource:
         self.resource_dict = None  # Filled in case yaml_file is not None
         self.config_file = config_file
         self.context = context
-        self.label = label
         if not (self.name or self.yaml_file):
             raise ValueError("name or yaml file is required")
 
@@ -407,10 +403,6 @@ class Resource:
                 "kind": self.kind,
                 "metadata": {"name": self.name},
             }
-            if self.label:
-                self.res.setdefault("metadata", {}).setdefault("labels", {}).update(
-                    self.label
-                )
 
     def to_dict(self):
         """
@@ -760,6 +752,7 @@ class Resource:
     def retry_cluster_exceptions(
         func, exceptions_dict=DEFAULT_CLUSTER_RETRY_EXCEPTIONS, **kwargs
     ):
+
         sampler = TimeoutSampler(
             wait_timeout=10,
             sleep=1,
